package com.biganto.visual.roompark.presentation.screen.feeds.utils

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.domain.model.AlbumPreviewModel
import com.squareup.picasso.Picasso
import java.text.SimpleDateFormat
import java.util.*


/**
 * Created by Vladislav Bogdashkin on 15.10.2019.
 */
class AlbumsPreviewAdapter : RecyclerView.Adapter<AlbumCardViewHolder>() {

    private var list: MutableList<AlbumPreviewModel> = mutableListOf()

    fun addItems(list:List<AlbumPreviewModel>){
        this.list.clear()
        this.list.addAll(list)
        notifyDataSetChanged()
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): AlbumCardViewHolder =
        AlbumCardViewHolder(
            LayoutInflater.from(parent.context)
                .inflate(R.layout.album_preview_card_viewholder, parent, false)
        )

    override fun getItemCount(): Int = list.size

    override fun onBindViewHolder(holder: AlbumCardViewHolder, position: Int) {
        holder.bindModel(list[position])
    }
}


class AlbumCardViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

    private val dateFormatter = SimpleDateFormat("dd MMMM yyyy", Locale("ru"))

    @BindView(R.id.preview) lateinit var preview:ImageView
    @BindView(R.id.card_title) lateinit var articleTitle:TextView
    @BindView(R.id.card_updated) lateinit var articleDate:TextView

    init {
        ButterKnife.bind(this, itemView)
    }

    fun bindModel(model: AlbumPreviewModel){
        articleDate.text = dateFormatter.format(model.published)
        articleTitle.text = model.title

        Picasso.get()
            .load(model.previewUrl)
            .into(preview)
    }

}
